/*******************************************************************************
  * Copyright 2025 Intel Corporation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *******************************************************************************/

  
#if !defined(_NO_IPP_DEPRECATED)
#pragma message ("code path e9 is deprecated, y8 optimizations level is used")
#endif
#define ippcpGetLibVersion y8_ippcpGetLibVersion
#define cryptoGetLibVersion y8_cryptoGetLibVersion
#define ippsDESGetSize y8_ippsDESGetSize
#define ippsDESInit y8_ippsDESInit
#define ippsDESPack y8_ippsDESPack
#define ippsDESUnpack y8_ippsDESUnpack
#define ippsTDESEncryptECB y8_ippsTDESEncryptECB
#define ippsTDESDecryptECB y8_ippsTDESDecryptECB
#define ippsTDESEncryptCBC y8_ippsTDESEncryptCBC
#define ippsTDESDecryptCBC y8_ippsTDESDecryptCBC
#define ippsTDESEncryptCFB y8_ippsTDESEncryptCFB
#define ippsTDESDecryptCFB y8_ippsTDESDecryptCFB
#define ippsTDESEncryptOFB y8_ippsTDESEncryptOFB
#define ippsTDESDecryptOFB y8_ippsTDESDecryptOFB
#define ippsTDESEncryptCTR y8_ippsTDESEncryptCTR
#define ippsTDESDecryptCTR y8_ippsTDESDecryptCTR
#define ippsAESGetSize y8_ippsAESGetSize
#define ippsAESInit y8_ippsAESInit
#define ippsAESSetKey y8_ippsAESSetKey
#define ippsAESPack y8_ippsAESPack
#define ippsAESUnpack y8_ippsAESUnpack
#define ippsAESEncryptECB y8_ippsAESEncryptECB
#define ippsAESDecryptECB y8_ippsAESDecryptECB
#define ippsAESEncryptCBC y8_ippsAESEncryptCBC
#define ippsAESEncryptCBC_CS1 y8_ippsAESEncryptCBC_CS1
#define ippsAESEncryptCBC_CS2 y8_ippsAESEncryptCBC_CS2
#define ippsAESEncryptCBC_CS3 y8_ippsAESEncryptCBC_CS3
#define ippsAESDecryptCBC y8_ippsAESDecryptCBC
#define ippsAESDecryptCBC_CS1 y8_ippsAESDecryptCBC_CS1
#define ippsAESDecryptCBC_CS2 y8_ippsAESDecryptCBC_CS2
#define ippsAESDecryptCBC_CS3 y8_ippsAESDecryptCBC_CS3
#define ippsAESEncryptCFB y8_ippsAESEncryptCFB
#define ippsAESDecryptCFB y8_ippsAESDecryptCFB
#define ippsAESEncryptOFB y8_ippsAESEncryptOFB
#define ippsAESDecryptOFB y8_ippsAESDecryptOFB
#define ippsAESEncryptCTR y8_ippsAESEncryptCTR
#define ippsAESDecryptCTR y8_ippsAESDecryptCTR
#define ippsAESEncryptXTS_Direct y8_ippsAESEncryptXTS_Direct
#define ippsAESDecryptXTS_Direct y8_ippsAESDecryptXTS_Direct
#define ippsAESSetupNoise y8_ippsAESSetupNoise
#define ippsAES_GCMSetupNoise y8_ippsAES_GCMSetupNoise
#define ippsAES_CMACSetupNoise y8_ippsAES_CMACSetupNoise
#define ippsAES_EncryptCFB16_MB y8_ippsAES_EncryptCFB16_MB
#define ippsSMS4GetSize y8_ippsSMS4GetSize
#define ippsSMS4Init y8_ippsSMS4Init
#define ippsSMS4SetKey y8_ippsSMS4SetKey
#define ippsSMS4EncryptECB y8_ippsSMS4EncryptECB
#define ippsSMS4DecryptECB y8_ippsSMS4DecryptECB
#define ippsSMS4EncryptCBC y8_ippsSMS4EncryptCBC
#define ippsSMS4EncryptCBC_CS1 y8_ippsSMS4EncryptCBC_CS1
#define ippsSMS4EncryptCBC_CS2 y8_ippsSMS4EncryptCBC_CS2
#define ippsSMS4EncryptCBC_CS3 y8_ippsSMS4EncryptCBC_CS3
#define ippsSMS4DecryptCBC y8_ippsSMS4DecryptCBC
#define ippsSMS4DecryptCBC_CS1 y8_ippsSMS4DecryptCBC_CS1
#define ippsSMS4DecryptCBC_CS2 y8_ippsSMS4DecryptCBC_CS2
#define ippsSMS4DecryptCBC_CS3 y8_ippsSMS4DecryptCBC_CS3
#define ippsSMS4EncryptCFB y8_ippsSMS4EncryptCFB
#define ippsSMS4DecryptCFB y8_ippsSMS4DecryptCFB
#define ippsSMS4EncryptOFB y8_ippsSMS4EncryptOFB
#define ippsSMS4DecryptOFB y8_ippsSMS4DecryptOFB
#define ippsSMS4EncryptCTR y8_ippsSMS4EncryptCTR
#define ippsSMS4DecryptCTR y8_ippsSMS4DecryptCTR
#define ippsSMS4_CCMGetSize y8_ippsSMS4_CCMGetSize
#define ippsSMS4_CCMInit y8_ippsSMS4_CCMInit
#define ippsSMS4_CCMMessageLen y8_ippsSMS4_CCMMessageLen
#define ippsSMS4_CCMTagLen y8_ippsSMS4_CCMTagLen
#define ippsSMS4_CCMStart y8_ippsSMS4_CCMStart
#define ippsSMS4_CCMEncrypt y8_ippsSMS4_CCMEncrypt
#define ippsSMS4_CCMDecrypt y8_ippsSMS4_CCMDecrypt
#define ippsSMS4_CCMGetTag y8_ippsSMS4_CCMGetTag
#define ippsAES_CCMGetSize y8_ippsAES_CCMGetSize
#define ippsAES_CCMInit y8_ippsAES_CCMInit
#define ippsAES_CCMMessageLen y8_ippsAES_CCMMessageLen
#define ippsAES_CCMTagLen y8_ippsAES_CCMTagLen
#define ippsAES_CCMStart y8_ippsAES_CCMStart
#define ippsAES_CCMEncrypt y8_ippsAES_CCMEncrypt
#define ippsAES_CCMDecrypt y8_ippsAES_CCMDecrypt
#define ippsAES_CCMGetTag y8_ippsAES_CCMGetTag
#define ippsAES_GCMGetSize y8_ippsAES_GCMGetSize
#define ippsAES_GCMInit y8_ippsAES_GCMInit
#define ippsAES_GCMReinit y8_ippsAES_GCMReinit
#define ippsAES_GCMReset y8_ippsAES_GCMReset
#define ippsAES_GCMProcessIV y8_ippsAES_GCMProcessIV
#define ippsAES_GCMProcessAAD y8_ippsAES_GCMProcessAAD
#define ippsAES_GCMStart y8_ippsAES_GCMStart
#define ippsAES_GCMEncrypt y8_ippsAES_GCMEncrypt
#define ippsAES_GCMDecrypt y8_ippsAES_GCMDecrypt
#define ippsAES_GCMGetTag y8_ippsAES_GCMGetTag
#define ippsAES_XTSGetSize y8_ippsAES_XTSGetSize
#define ippsAES_XTSInit y8_ippsAES_XTSInit
#define ippsAES_XTSEncrypt y8_ippsAES_XTSEncrypt
#define ippsAES_XTSDecrypt y8_ippsAES_XTSDecrypt
#define ippsAES_S2V_CMAC y8_ippsAES_S2V_CMAC
#define ippsAES_SIVEncrypt y8_ippsAES_SIVEncrypt
#define ippsAES_SIVDecrypt y8_ippsAES_SIVDecrypt
#define ippsAES_CMACGetSize y8_ippsAES_CMACGetSize
#define ippsAES_CMACInit y8_ippsAES_CMACInit
#define ippsAES_CMACUpdate y8_ippsAES_CMACUpdate
#define ippsAES_CMACFinal y8_ippsAES_CMACFinal
#define ippsAES_CMACGetTag y8_ippsAES_CMACGetTag
#define ippsARCFourCheckKey y8_ippsARCFourCheckKey
#define ippsARCFourGetSize y8_ippsARCFourGetSize
#define ippsARCFourInit y8_ippsARCFourInit
#define ippsARCFourReset y8_ippsARCFourReset
#define ippsARCFourPack y8_ippsARCFourPack
#define ippsARCFourUnpack y8_ippsARCFourUnpack
#define ippsARCFourEncrypt y8_ippsARCFourEncrypt
#define ippsARCFourDecrypt y8_ippsARCFourDecrypt
#define ippsHashGetSize y8_ippsHashGetSize
#define ippsHashInit y8_ippsHashInit
#define ippsHashPack y8_ippsHashPack
#define ippsHashUnpack y8_ippsHashUnpack
#define ippsHashDuplicate y8_ippsHashDuplicate
#define ippsHashUpdate y8_ippsHashUpdate
#define ippsHashGetTag y8_ippsHashGetTag
#define ippsHashFinal y8_ippsHashFinal
#define ippsHashMessage y8_ippsHashMessage
#define ippsHashMethod_MD5 y8_ippsHashMethod_MD5
#define ippsHashMethod_SM3 y8_ippsHashMethod_SM3
#define ippsHashMethod_SM3_NI y8_ippsHashMethod_SM3_NI
#define ippsHashMethod_SM3_TT y8_ippsHashMethod_SM3_TT
#define ippsHashMethod_SHA1 y8_ippsHashMethod_SHA1
#define ippsHashMethod_SHA1_NI y8_ippsHashMethod_SHA1_NI
#define ippsHashMethod_SHA1_TT y8_ippsHashMethod_SHA1_TT
#define ippsHashMethod_SHA256 y8_ippsHashMethod_SHA256
#define ippsHashMethod_SHA256_NI y8_ippsHashMethod_SHA256_NI
#define ippsHashMethod_SHA256_TT y8_ippsHashMethod_SHA256_TT
#define ippsHashMethod_SHA224 y8_ippsHashMethod_SHA224
#define ippsHashMethod_SHA224_NI y8_ippsHashMethod_SHA224_NI
#define ippsHashMethod_SHA224_TT y8_ippsHashMethod_SHA224_TT
#define ippsHashMethod_SHA512 y8_ippsHashMethod_SHA512
#define ippsHashMethod_SHA512_NI y8_ippsHashMethod_SHA512_NI
#define ippsHashMethod_SHA512_TT y8_ippsHashMethod_SHA512_TT
#define ippsHashMethod_SHA384 y8_ippsHashMethod_SHA384
#define ippsHashMethod_SHA384_NI y8_ippsHashMethod_SHA384_NI
#define ippsHashMethod_SHA384_TT y8_ippsHashMethod_SHA384_TT
#define ippsHashMethod_SHA512_256 y8_ippsHashMethod_SHA512_256
#define ippsHashMethod_SHA512_256_NI y8_ippsHashMethod_SHA512_256_NI
#define ippsHashMethod_SHA512_256_TT y8_ippsHashMethod_SHA512_256_TT
#define ippsHashMethod_SHA512_224 y8_ippsHashMethod_SHA512_224
#define ippsHashMethod_SHA512_224_NI y8_ippsHashMethod_SHA512_224_NI
#define ippsHashMethod_SHA512_224_TT y8_ippsHashMethod_SHA512_224_TT
#define ippsHashMethod_SHA3_224 y8_ippsHashMethod_SHA3_224
#define ippsHashMethod_SHA3_256 y8_ippsHashMethod_SHA3_256
#define ippsHashMethod_SHA3_384 y8_ippsHashMethod_SHA3_384
#define ippsHashMethod_SHA3_512 y8_ippsHashMethod_SHA3_512
#define ippsHashMethod_SHAKE128 y8_ippsHashMethod_SHAKE128
#define ippsHashMethod_SHAKE256 y8_ippsHashMethod_SHAKE256
#define ippsHashMethodGetSize y8_ippsHashMethodGetSize
#define ippsHashMethodSet_MD5 y8_ippsHashMethodSet_MD5
#define ippsHashMethodSet_SM3 y8_ippsHashMethodSet_SM3
#define ippsHashMethodSet_SM3_NI y8_ippsHashMethodSet_SM3_NI
#define ippsHashMethodSet_SM3_TT y8_ippsHashMethodSet_SM3_TT
#define ippsHashMethodSet_SHA1 y8_ippsHashMethodSet_SHA1
#define ippsHashMethodSet_SHA1_NI y8_ippsHashMethodSet_SHA1_NI
#define ippsHashMethodSet_SHA1_TT y8_ippsHashMethodSet_SHA1_TT
#define ippsHashMethodSet_SHA224 y8_ippsHashMethodSet_SHA224
#define ippsHashMethodSet_SHA224_NI y8_ippsHashMethodSet_SHA224_NI
#define ippsHashMethodSet_SHA224_TT y8_ippsHashMethodSet_SHA224_TT
#define ippsHashMethodSet_SHA256 y8_ippsHashMethodSet_SHA256
#define ippsHashMethodSet_SHA256_NI y8_ippsHashMethodSet_SHA256_NI
#define ippsHashMethodSet_SHA256_TT y8_ippsHashMethodSet_SHA256_TT
#define ippsHashMethodSet_SHA384 y8_ippsHashMethodSet_SHA384
#define ippsHashMethodSet_SHA384_NI y8_ippsHashMethodSet_SHA384_NI
#define ippsHashMethodSet_SHA384_TT y8_ippsHashMethodSet_SHA384_TT
#define ippsHashMethodSet_SHA512 y8_ippsHashMethodSet_SHA512
#define ippsHashMethodSet_SHA512_NI y8_ippsHashMethodSet_SHA512_NI
#define ippsHashMethodSet_SHA512_TT y8_ippsHashMethodSet_SHA512_TT
#define ippsHashMethodSet_SHA512_224 y8_ippsHashMethodSet_SHA512_224
#define ippsHashMethodSet_SHA512_224_NI y8_ippsHashMethodSet_SHA512_224_NI
#define ippsHashMethodSet_SHA512_224_TT y8_ippsHashMethodSet_SHA512_224_TT
#define ippsHashMethodSet_SHA512_256 y8_ippsHashMethodSet_SHA512_256
#define ippsHashMethodSet_SHA512_256_NI y8_ippsHashMethodSet_SHA512_256_NI
#define ippsHashMethodSet_SHA512_256_TT y8_ippsHashMethodSet_SHA512_256_TT
#define ippsHashMethodSet_SHA3_224 y8_ippsHashMethodSet_SHA3_224
#define ippsHashMethodSet_SHA3_256 y8_ippsHashMethodSet_SHA3_256
#define ippsHashMethodSet_SHA3_384 y8_ippsHashMethodSet_SHA3_384
#define ippsHashMethodSet_SHA3_512 y8_ippsHashMethodSet_SHA3_512
#define ippsHashMethodSet_SHAKE128 y8_ippsHashMethodSet_SHAKE128
#define ippsHashMethodSet_SHAKE256 y8_ippsHashMethodSet_SHAKE256
#define ippsHashStateMethodSet_SM3 y8_ippsHashStateMethodSet_SM3
#define ippsHashStateMethodSet_SM3_NI y8_ippsHashStateMethodSet_SM3_NI
#define ippsHashStateMethodSet_SM3_TT y8_ippsHashStateMethodSet_SM3_TT
#define ippsHashStateMethodSet_SHA256 y8_ippsHashStateMethodSet_SHA256
#define ippsHashStateMethodSet_SHA256_NI y8_ippsHashStateMethodSet_SHA256_NI
#define ippsHashStateMethodSet_SHA256_TT y8_ippsHashStateMethodSet_SHA256_TT
#define ippsHashStateMethodSet_SHA224 y8_ippsHashStateMethodSet_SHA224
#define ippsHashStateMethodSet_SHA224_NI y8_ippsHashStateMethodSet_SHA224_NI
#define ippsHashStateMethodSet_SHA224_TT y8_ippsHashStateMethodSet_SHA224_TT
#define ippsHashStateMethodSet_SHA512 y8_ippsHashStateMethodSet_SHA512
#define ippsHashStateMethodSet_SHA512_NI y8_ippsHashStateMethodSet_SHA512_NI
#define ippsHashStateMethodSet_SHA512_TT y8_ippsHashStateMethodSet_SHA512_TT
#define ippsHashStateMethodSet_SHA384 y8_ippsHashStateMethodSet_SHA384
#define ippsHashStateMethodSet_SHA384_NI y8_ippsHashStateMethodSet_SHA384_NI
#define ippsHashStateMethodSet_SHA384_TT y8_ippsHashStateMethodSet_SHA384_TT
#define ippsHashStateMethodSet_SHA512_256 y8_ippsHashStateMethodSet_SHA512_256
#define ippsHashStateMethodSet_SHA512_256_NI y8_ippsHashStateMethodSet_SHA512_256_NI
#define ippsHashStateMethodSet_SHA512_256_TT y8_ippsHashStateMethodSet_SHA512_256_TT
#define ippsHashStateMethodSet_SHA512_224 y8_ippsHashStateMethodSet_SHA512_224
#define ippsHashStateMethodSet_SHA512_224_NI y8_ippsHashStateMethodSet_SHA512_224_NI
#define ippsHashStateMethodSet_SHA512_224_TT y8_ippsHashStateMethodSet_SHA512_224_TT
#define ippsHashStateMethodSet_SHA3_224 y8_ippsHashStateMethodSet_SHA3_224
#define ippsHashStateMethodSet_SHA3_256 y8_ippsHashStateMethodSet_SHA3_256
#define ippsHashStateMethodSet_SHA3_384 y8_ippsHashStateMethodSet_SHA3_384
#define ippsHashStateMethodSet_SHA3_512 y8_ippsHashStateMethodSet_SHA3_512
#define ippsHashStateMethodSet_SHAKE128 y8_ippsHashStateMethodSet_SHAKE128
#define ippsHashStateMethodSet_SHAKE256 y8_ippsHashStateMethodSet_SHAKE256
#define ippsHashGetSize_rmf y8_ippsHashGetSize_rmf
#define ippsHashGetSizeOptimal_rmf y8_ippsHashGetSizeOptimal_rmf
#define ippsHashInit_rmf y8_ippsHashInit_rmf
#define ippsHashPack_rmf y8_ippsHashPack_rmf
#define ippsHashUnpack_rmf y8_ippsHashUnpack_rmf
#define ippsHashDuplicate_rmf y8_ippsHashDuplicate_rmf
#define ippsHashUpdate_rmf y8_ippsHashUpdate_rmf
#define ippsHashGetTag_rmf y8_ippsHashGetTag_rmf
#define ippsHashFinal_rmf y8_ippsHashFinal_rmf
#define ippsHashMessage_rmf y8_ippsHashMessage_rmf
#define ippsHashMethodGetInfo y8_ippsHashMethodGetInfo
#define ippsHashGetInfo_rmf y8_ippsHashGetInfo_rmf
#define ippsHashSqueeze_rmf y8_ippsHashSqueeze_rmf
#define ippsMGF y8_ippsMGF
#define ippsMGF1_rmf y8_ippsMGF1_rmf
#define ippsMGF2_rmf y8_ippsMGF2_rmf
#define ippsHMAC_GetSize y8_ippsHMAC_GetSize
#define ippsHMAC_Init y8_ippsHMAC_Init
#define ippsHMAC_Pack y8_ippsHMAC_Pack
#define ippsHMAC_Unpack y8_ippsHMAC_Unpack
#define ippsHMAC_Duplicate y8_ippsHMAC_Duplicate
#define ippsHMAC_Update y8_ippsHMAC_Update
#define ippsHMAC_Final y8_ippsHMAC_Final
#define ippsHMAC_GetTag y8_ippsHMAC_GetTag
#define ippsHMAC_Message y8_ippsHMAC_Message
#define ippsHMACGetSize_rmf y8_ippsHMACGetSize_rmf
#define ippsHMACInit_rmf y8_ippsHMACInit_rmf
#define ippsHMACPack_rmf y8_ippsHMACPack_rmf
#define ippsHMACUnpack_rmf y8_ippsHMACUnpack_rmf
#define ippsHMACDuplicate_rmf y8_ippsHMACDuplicate_rmf
#define ippsHMACUpdate_rmf y8_ippsHMACUpdate_rmf
#define ippsHMACFinal_rmf y8_ippsHMACFinal_rmf
#define ippsHMACGetTag_rmf y8_ippsHMACGetTag_rmf
#define ippsHMACMessage_rmf y8_ippsHMACMessage_rmf
#define ippsHKDF y8_ippsHKDF
#define ippsHKDF_extract y8_ippsHKDF_extract
#define ippsHKDF_expand y8_ippsHKDF_expand
#define ippsBigNumGetSize y8_ippsBigNumGetSize
#define ippsBigNumInit y8_ippsBigNumInit
#define ippsCmpZero_BN y8_ippsCmpZero_BN
#define ippsCmp_BN y8_ippsCmp_BN
#define ippsGetSize_BN y8_ippsGetSize_BN
#define ippsSet_BN y8_ippsSet_BN
#define ippsGet_BN y8_ippsGet_BN
#define ippsRef_BN y8_ippsRef_BN
#define ippsExtGet_BN y8_ippsExtGet_BN
#define ippsAdd_BN y8_ippsAdd_BN
#define ippsSub_BN y8_ippsSub_BN
#define ippsMul_BN y8_ippsMul_BN
#define ippsMAC_BN_I y8_ippsMAC_BN_I
#define ippsDiv_BN y8_ippsDiv_BN
#define ippsMod_BN y8_ippsMod_BN
#define ippsGcd_BN y8_ippsGcd_BN
#define ippsModInv_BN y8_ippsModInv_BN
#define ippsSetOctString_BN y8_ippsSetOctString_BN
#define ippsGetOctString_BN y8_ippsGetOctString_BN
#define ippsMontGetSize y8_ippsMontGetSize
#define ippsMontInit y8_ippsMontInit
#define ippsMontSet y8_ippsMontSet
#define ippsMontGet y8_ippsMontGet
#define ippsMontForm y8_ippsMontForm
#define ippsMontMul y8_ippsMontMul
#define ippsMontExp y8_ippsMontExp
#define ippsPRNGGetSize y8_ippsPRNGGetSize
#define ippsPRNGInit y8_ippsPRNGInit
#define ippsPRNGSetModulus y8_ippsPRNGSetModulus
#define ippsPRNGSetH0 y8_ippsPRNGSetH0
#define ippsPRNGSetAugment y8_ippsPRNGSetAugment
#define ippsPRNGSetSeed y8_ippsPRNGSetSeed
#define ippsPRNGGetSeed y8_ippsPRNGGetSeed
#define ippsPRNGen y8_ippsPRNGen
#define ippsPRNGen_BN y8_ippsPRNGen_BN
#define ippsPRNGenRDRAND y8_ippsPRNGenRDRAND
#define ippsPRNGenRDRAND_BN y8_ippsPRNGenRDRAND_BN
#define ippsTRNGenRDSEED y8_ippsTRNGenRDSEED
#define ippsTRNGenRDSEED_BN y8_ippsTRNGenRDSEED_BN
#define ippsPrimeGetSize y8_ippsPrimeGetSize
#define ippsPrimeInit y8_ippsPrimeInit
#define ippsPrimeGen y8_ippsPrimeGen
#define ippsPrimeTest y8_ippsPrimeTest
#define ippsPrimeGen_BN y8_ippsPrimeGen_BN
#define ippsPrimeTest_BN y8_ippsPrimeTest_BN
#define ippsPrimeGet y8_ippsPrimeGet
#define ippsPrimeGet_BN y8_ippsPrimeGet_BN
#define ippsPrimeSet y8_ippsPrimeSet
#define ippsPrimeSet_BN y8_ippsPrimeSet_BN
#define ippsRSA_GetSizePublicKey y8_ippsRSA_GetSizePublicKey
#define ippsRSA_InitPublicKey y8_ippsRSA_InitPublicKey
#define ippsRSA_SetPublicKey y8_ippsRSA_SetPublicKey
#define ippsRSA_GetPublicKey y8_ippsRSA_GetPublicKey
#define ippsRSA_GetSizePrivateKeyType1 y8_ippsRSA_GetSizePrivateKeyType1
#define ippsRSA_InitPrivateKeyType1 y8_ippsRSA_InitPrivateKeyType1
#define ippsRSA_SetPrivateKeyType1 y8_ippsRSA_SetPrivateKeyType1
#define ippsRSA_GetPrivateKeyType1 y8_ippsRSA_GetPrivateKeyType1
#define ippsRSA_GetSizePrivateKeyType2 y8_ippsRSA_GetSizePrivateKeyType2
#define ippsRSA_InitPrivateKeyType2 y8_ippsRSA_InitPrivateKeyType2
#define ippsRSA_SetPrivateKeyType2 y8_ippsRSA_SetPrivateKeyType2
#define ippsRSA_GetPrivateKeyType2 y8_ippsRSA_GetPrivateKeyType2
#define ippsRSA_GetBufferSizePublicKey y8_ippsRSA_GetBufferSizePublicKey
#define ippsRSA_GetBufferSizePrivateKey y8_ippsRSA_GetBufferSizePrivateKey
#define ippsRSA_Encrypt y8_ippsRSA_Encrypt
#define ippsRSA_Decrypt y8_ippsRSA_Decrypt
#define ippsRSA_GenerateKeys y8_ippsRSA_GenerateKeys
#define ippsRSA_ValidateKeys y8_ippsRSA_ValidateKeys
#define ippsRSAEncrypt_OAEP y8_ippsRSAEncrypt_OAEP
#define ippsRSADecrypt_OAEP y8_ippsRSADecrypt_OAEP
#define ippsRSAEncrypt_OAEP_rmf y8_ippsRSAEncrypt_OAEP_rmf
#define ippsRSADecrypt_OAEP_rmf y8_ippsRSADecrypt_OAEP_rmf
#define ippsRSAEncrypt_PKCSv15 y8_ippsRSAEncrypt_PKCSv15
#define ippsRSADecrypt_PKCSv15 y8_ippsRSADecrypt_PKCSv15
#define ippsRSASign_PSS y8_ippsRSASign_PSS
#define ippsRSAVerify_PSS y8_ippsRSAVerify_PSS
#define ippsRSASign_PSS_rmf y8_ippsRSASign_PSS_rmf
#define ippsRSAVerify_PSS_rmf y8_ippsRSAVerify_PSS_rmf
#define ippsRSASign_PKCS1v15 y8_ippsRSASign_PKCS1v15
#define ippsRSAVerify_PKCS1v15 y8_ippsRSAVerify_PKCS1v15
#define ippsRSASign_PKCS1v15_rmf y8_ippsRSASign_PKCS1v15_rmf
#define ippsRSAVerify_PKCS1v15_rmf y8_ippsRSAVerify_PKCS1v15_rmf
#define ippsDLGetResultString y8_ippsDLGetResultString
#define ippsDLPGetSize y8_ippsDLPGetSize
#define ippsDLPInit y8_ippsDLPInit
#define ippsDLPPack y8_ippsDLPPack
#define ippsDLPUnpack y8_ippsDLPUnpack
#define ippsDLPSet y8_ippsDLPSet
#define ippsDLPGet y8_ippsDLPGet
#define ippsDLPSetDP y8_ippsDLPSetDP
#define ippsDLPGetDP y8_ippsDLPGetDP
#define ippsDLPGenKeyPair y8_ippsDLPGenKeyPair
#define ippsDLPPublicKey y8_ippsDLPPublicKey
#define ippsDLPValidateKeyPair y8_ippsDLPValidateKeyPair
#define ippsDLPSetKeyPair y8_ippsDLPSetKeyPair
#define ippsDLPSignDSA y8_ippsDLPSignDSA
#define ippsDLPVerifyDSA y8_ippsDLPVerifyDSA
#define ippsDLPSharedSecretDH y8_ippsDLPSharedSecretDH
#define ippsDLPGenerateDSA y8_ippsDLPGenerateDSA
#define ippsDLPValidateDSA y8_ippsDLPValidateDSA
#define ippsDLPGenerateDH y8_ippsDLPGenerateDH
#define ippsDLPValidateDH y8_ippsDLPValidateDH
#define ippsECCGetResultString y8_ippsECCGetResultString
#define ippsGFpGetSize y8_ippsGFpGetSize
#define ippsGFpInitArbitrary y8_ippsGFpInitArbitrary
#define ippsGFpInitFixed y8_ippsGFpInitFixed
#define ippsGFpInit y8_ippsGFpInit
#define ippsGFpMethod_p192r1 y8_ippsGFpMethod_p192r1
#define ippsGFpMethod_p224r1 y8_ippsGFpMethod_p224r1
#define ippsGFpMethod_p256r1 y8_ippsGFpMethod_p256r1
#define ippsGFpMethod_p384r1 y8_ippsGFpMethod_p384r1
#define ippsGFpMethod_p521r1 y8_ippsGFpMethod_p521r1
#define ippsGFpMethod_p256sm2 y8_ippsGFpMethod_p256sm2
#define ippsGFpMethod_p256bn y8_ippsGFpMethod_p256bn
#define ippsGFpMethod_p256 y8_ippsGFpMethod_p256
#define ippsGFpMethod_pArb y8_ippsGFpMethod_pArb
#define ippsGFpxGetSize y8_ippsGFpxGetSize
#define ippsGFpxInit y8_ippsGFpxInit
#define ippsGFpxInitBinomial y8_ippsGFpxInitBinomial
#define ippsGFpxMethod_binom2_epid2 y8_ippsGFpxMethod_binom2_epid2
#define ippsGFpxMethod_binom3_epid2 y8_ippsGFpxMethod_binom3_epid2
#define ippsGFpxMethod_binom2 y8_ippsGFpxMethod_binom2
#define ippsGFpxMethod_binom3 y8_ippsGFpxMethod_binom3
#define ippsGFpxMethod_binom y8_ippsGFpxMethod_binom
#define ippsGFpxMethod_com y8_ippsGFpxMethod_com
#define ippsGFpScratchBufferSize y8_ippsGFpScratchBufferSize
#define ippsGFpElementGetSize y8_ippsGFpElementGetSize
#define ippsGFpElementInit y8_ippsGFpElementInit
#define ippsGFpSetElement y8_ippsGFpSetElement
#define ippsGFpSetElementRegular y8_ippsGFpSetElementRegular
#define ippsGFpSetElementOctString y8_ippsGFpSetElementOctString
#define ippsGFpSetElementRandom y8_ippsGFpSetElementRandom
#define ippsGFpSetElementHash y8_ippsGFpSetElementHash
#define ippsGFpSetElementHash_rmf y8_ippsGFpSetElementHash_rmf
#define ippsGFpCpyElement y8_ippsGFpCpyElement
#define ippsGFpGetElement y8_ippsGFpGetElement
#define ippsGFpGetElementOctString y8_ippsGFpGetElementOctString
#define ippsGFpCmpElement y8_ippsGFpCmpElement
#define ippsGFpIsZeroElement y8_ippsGFpIsZeroElement
#define ippsGFpIsUnityElement y8_ippsGFpIsUnityElement
#define ippsGFpConj y8_ippsGFpConj
#define ippsGFpNeg y8_ippsGFpNeg
#define ippsGFpInv y8_ippsGFpInv
#define ippsGFpSqrt y8_ippsGFpSqrt
#define ippsGFpSqr y8_ippsGFpSqr
#define ippsGFpAdd y8_ippsGFpAdd
#define ippsGFpSub y8_ippsGFpSub
#define ippsGFpMul y8_ippsGFpMul
#define ippsGFpExp y8_ippsGFpExp
#define ippsGFpMultiExp y8_ippsGFpMultiExp
#define ippsGFpAdd_PE y8_ippsGFpAdd_PE
#define ippsGFpSub_PE y8_ippsGFpSub_PE
#define ippsGFpMul_PE y8_ippsGFpMul_PE
#define ippsGFpGetInfo y8_ippsGFpGetInfo
#define ippsGFpECGetSize y8_ippsGFpECGetSize
#define ippsGFpECInit y8_ippsGFpECInit
#define ippsGFpECSet y8_ippsGFpECSet
#define ippsGFpECSetSubgroup y8_ippsGFpECSetSubgroup
#define ippsGFpECInitStd128r1 y8_ippsGFpECInitStd128r1
#define ippsGFpECInitStd128r2 y8_ippsGFpECInitStd128r2
#define ippsGFpECInitStd192r1 y8_ippsGFpECInitStd192r1
#define ippsGFpECInitStd224r1 y8_ippsGFpECInitStd224r1
#define ippsGFpECInitStd256r1 y8_ippsGFpECInitStd256r1
#define ippsGFpECInitStd384r1 y8_ippsGFpECInitStd384r1
#define ippsGFpECInitStd521r1 y8_ippsGFpECInitStd521r1
#define ippsGFpECInitStdSM2 y8_ippsGFpECInitStdSM2
#define ippsGFpECInitStdBN256 y8_ippsGFpECInitStdBN256
#define ippsGFpECBindGxyTblStd192r1 y8_ippsGFpECBindGxyTblStd192r1
#define ippsGFpECBindGxyTblStd224r1 y8_ippsGFpECBindGxyTblStd224r1
#define ippsGFpECBindGxyTblStd256r1 y8_ippsGFpECBindGxyTblStd256r1
#define ippsGFpECBindGxyTblStd384r1 y8_ippsGFpECBindGxyTblStd384r1
#define ippsGFpECBindGxyTblStd521r1 y8_ippsGFpECBindGxyTblStd521r1
#define ippsGFpECBindGxyTblStdSM2 y8_ippsGFpECBindGxyTblStdSM2
#define ippsGFpECGet y8_ippsGFpECGet
#define ippsGFpECGetSubgroup y8_ippsGFpECGetSubgroup
#define ippsGFpECScratchBufferSize y8_ippsGFpECScratchBufferSize
#define ippsGFpECVerify y8_ippsGFpECVerify
#define ippsGFpECPointGetSize y8_ippsGFpECPointGetSize
#define ippsGFpECPointInit y8_ippsGFpECPointInit
#define ippsGFpECSetPointAtInfinity y8_ippsGFpECSetPointAtInfinity
#define ippsGFpECSetPoint y8_ippsGFpECSetPoint
#define ippsGFpECSetPointRegular y8_ippsGFpECSetPointRegular
#define ippsGFpECSetPointRandom y8_ippsGFpECSetPointRandom
#define ippsGFpECMakePoint y8_ippsGFpECMakePoint
#define ippsGFpECSetPointHash y8_ippsGFpECSetPointHash
#define ippsGFpECSetPointHashBackCompatible y8_ippsGFpECSetPointHashBackCompatible
#define ippsGFpECSetPointHash_rmf y8_ippsGFpECSetPointHash_rmf
#define ippsGFpECSetPointHashBackCompatible_rmf y8_ippsGFpECSetPointHashBackCompatible_rmf
#define ippsGFpECGetPoint y8_ippsGFpECGetPoint
#define ippsGFpECGetPointRegular y8_ippsGFpECGetPointRegular
#define ippsGFpECSetPointOctString y8_ippsGFpECSetPointOctString
#define ippsGFpECGetPointOctString y8_ippsGFpECGetPointOctString
#define ippsGFpECTstPoint y8_ippsGFpECTstPoint
#define ippsGFpECTstPointInSubgroup y8_ippsGFpECTstPointInSubgroup
#define ippsGFpECCpyPoint y8_ippsGFpECCpyPoint
#define ippsGFpECCmpPoint y8_ippsGFpECCmpPoint
#define ippsGFpECNegPoint y8_ippsGFpECNegPoint
#define ippsGFpECAddPoint y8_ippsGFpECAddPoint
#define ippsGFpECMulPoint y8_ippsGFpECMulPoint
#define ippsGFpECPrivateKey y8_ippsGFpECPrivateKey
#define ippsGFpECPublicKey y8_ippsGFpECPublicKey
#define ippsGFpECTstKeyPair y8_ippsGFpECTstKeyPair
#define ippsGFpECSharedSecretDH y8_ippsGFpECSharedSecretDH
#define ippsGFpECSharedSecretDHC y8_ippsGFpECSharedSecretDHC
#define ippsGFpECMessageRepresentationSM2 y8_ippsGFpECMessageRepresentationSM2
#define ippsGFpECSignDSA y8_ippsGFpECSignDSA
#define ippsGFpECVerifyDSA y8_ippsGFpECVerifyDSA
#define ippsGFpECSignNR y8_ippsGFpECSignNR
#define ippsGFpECVerifyNR y8_ippsGFpECVerifyNR
#define ippsGFpECSignSM2 y8_ippsGFpECSignSM2
#define ippsGFpECVerifySM2 y8_ippsGFpECVerifySM2
#define ippsGFpECUserIDHashSM2 y8_ippsGFpECUserIDHashSM2
#define ippsGFpECKeyExchangeSM2_GetSize y8_ippsGFpECKeyExchangeSM2_GetSize
#define ippsGFpECKeyExchangeSM2_Init y8_ippsGFpECKeyExchangeSM2_Init
#define ippsGFpECKeyExchangeSM2_Setup y8_ippsGFpECKeyExchangeSM2_Setup
#define ippsGFpECKeyExchangeSM2_SharedKey y8_ippsGFpECKeyExchangeSM2_SharedKey
#define ippsGFpECKeyExchangeSM2_Confirm y8_ippsGFpECKeyExchangeSM2_Confirm
#define ippsGFpECGetInfo_GF y8_ippsGFpECGetInfo_GF
#define ippsGFpECESGetSize_SM2 y8_ippsGFpECESGetSize_SM2
#define ippsGFpECESInit_SM2 y8_ippsGFpECESInit_SM2
#define ippsGFpECESSetKey_SM2 y8_ippsGFpECESSetKey_SM2
#define ippsGFpECESStart_SM2 y8_ippsGFpECESStart_SM2
#define ippsGFpECESEncrypt_SM2 y8_ippsGFpECESEncrypt_SM2
#define ippsGFpECESDecrypt_SM2 y8_ippsGFpECESDecrypt_SM2
#define ippsGFpECESFinal_SM2 y8_ippsGFpECESFinal_SM2
#define ippsGFpECESGetBuffersSize_SM2 y8_ippsGFpECESGetBuffersSize_SM2
#define ippsGFpECEncryptSM2_Ext_EncMsgSize y8_ippsGFpECEncryptSM2_Ext_EncMsgSize
#define ippsGFpECEncryptSM2_Ext y8_ippsGFpECEncryptSM2_Ext
#define ippsGFpECDecryptSM2_Ext_DecMsgSize y8_ippsGFpECDecryptSM2_Ext_DecMsgSize
#define ippsGFpECDecryptSM2_Ext y8_ippsGFpECDecryptSM2_Ext
#define ippsXMSSBufferGetSize y8_ippsXMSSBufferGetSize
#define ippsXMSSVerifyBufferGetSize y8_ippsXMSSVerifyBufferGetSize
#define ippsXMSSKeyGenBufferGetSize y8_ippsXMSSKeyGenBufferGetSize
#define ippsXMSSSignBufferGetSize y8_ippsXMSSSignBufferGetSize
#define ippsXMSSPrivateKeyStateGetSize y8_ippsXMSSPrivateKeyStateGetSize
#define ippsXMSSPublicKeyStateGetSize y8_ippsXMSSPublicKeyStateGetSize
#define ippsXMSSSignatureStateGetSize y8_ippsXMSSSignatureStateGetSize
#define ippsXMSSInitSignature y8_ippsXMSSInitSignature
#define ippsXMSSInitKeyPair y8_ippsXMSSInitKeyPair
#define ippsXMSSSetPublicKeyState y8_ippsXMSSSetPublicKeyState
#define ippsXMSSSetSignatureState y8_ippsXMSSSetSignatureState
#define ippsXMSSKeyGen y8_ippsXMSSKeyGen
#define ippsXMSSSign y8_ippsXMSSSign
#define ippsXMSSVerify y8_ippsXMSSVerify
#define ippsLMSBufferGetSize y8_ippsLMSBufferGetSize
#define ippsLMSVerifyBufferGetSize y8_ippsLMSVerifyBufferGetSize
#define ippsLMSSignatureStateGetSize y8_ippsLMSSignatureStateGetSize
#define ippsLMSPublicKeyStateGetSize y8_ippsLMSPublicKeyStateGetSize
#define ippsLMSSetPublicKeyState y8_ippsLMSSetPublicKeyState
#define ippsLMSSetSignatureState y8_ippsLMSSetSignatureState
#define ippsLMSVerify y8_ippsLMSVerify
#define ippsMLKEM_GetSize y8_ippsMLKEM_GetSize
#define ippsMLKEM_GetInfo y8_ippsMLKEM_GetInfo
#define ippsMLKEM_Init y8_ippsMLKEM_Init
#define ippsMLKEM_KeyGenBufferGetSize y8_ippsMLKEM_KeyGenBufferGetSize
#define ippsMLKEM_EncapsBufferGetSize y8_ippsMLKEM_EncapsBufferGetSize
#define ippsMLKEM_DecapsBufferGetSize y8_ippsMLKEM_DecapsBufferGetSize
#define ippsMLKEM_KeyGen y8_ippsMLKEM_KeyGen
#define ippsMLKEM_Encaps y8_ippsMLKEM_Encaps
#define ippsMLKEM_Decaps y8_ippsMLKEM_Decaps
